@@ -11,6 +11,6 @@ class UnicodeCSVDictReader(csv.DictReader):
         line = csv.DictReader.next(self)
         line = dict(zip(
             line.keys(),
-            map(lambda v: v.decode(self.encoding), line.values())))
+            map(lambda v: v.decode(self.encoding).trim(), line.values())))
         return line
 
